Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(182)

Unified Diff: components/user_manager/user.h

Issue 1747843002: Rename raw_image() to image_bytes() in UserImage (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: address comments Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/webui/options/chromeos/user_image_source.cc ('k') | components/user_manager/user.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/user_manager/user.h
diff --git a/components/user_manager/user.h b/components/user_manager/user.h
index 0d6431b6ebc670748a811d379398eb204f425490..df3d5cbc18853314c0df0a99af5087c2a9658b4f 100644
--- a/components/user_manager/user.h
+++ b/components/user_manager/user.h
@@ -127,13 +127,13 @@ class USER_MANAGER_EXPORT User : public UserInfo {
bool HasDefaultImage() const;
int image_index() const { return image_index_; }
- bool has_raw_image() const { return user_image_.has_raw_image(); }
- // Returns raw representation of static user image.
- const UserImage::RawImage& raw_image() const {
- return user_image_.raw_image();
+ bool has_image_bytes() const { return user_image_.has_image_bytes(); }
+ // Returns bytes representation of static user image for WebUI.
+ const UserImage::Bytes& image_bytes() const {
+ return user_image_.image_bytes();
}
- // Whether |raw_image| contains data in format that is considered safe to
+ // Whether |user_image_| contains data in format that is considered safe to
// decode in sensitive environment (on Login screen).
bool image_is_safe_format() const { return user_image_.is_safe_format(); }
« no previous file with comments | « chrome/browser/ui/webui/options/chromeos/user_image_source.cc ('k') | components/user_manager/user.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698